@@ -24,7 +24,7 @@ impl Procedures for Cash {
 }
 
 impl Cash {
-    pub fn new(currency: String, amount: i64) -> Self {
+    pub fn new(currency: &str, amount: i64) -> Self {
         Self {
             currency: String::from(currency),
             amount: amount,
